@@ -3,10 +3,8 @@ import logging
 from typing import Optional
 
 from lexicon.providers import dnsmadeeasy
-import zope.interface
 
 from certbot import errors
-from certbot import interfaces
 from certbot.plugins import dns_common
 from certbot.plugins import dns_common_lexicon
 from certbot.plugins.dns_common import CredentialsConfiguration
@@ -16,8 +14,6 @@ logger = logging.getLogger(__name__)
 ACCOUNT_URL = 'https://cp.dnsmadeeasy.com/account/info'
 
 
-@zope.interface.implementer(interfaces.IAuthenticator)
-@zope.interface.provider(interfaces.IPluginFactory)
 class Authenticator(dns_common.DNSAuthenticator):
     """DNS Authenticator for DNS Made Easy
 
